import { getSelectData } from './select';
import { getJudgeData } from './judge';
import { fillData } from './fill';
import { getSortDataTemplate } from './sort';
import { getMatchingDataTemplate } from './matching';
import { ChooseToneData } from './chooseTone';
import { essayQuestionData } from './essayQuestion';
import { readAloudData } from './readAloud';
import { repeatData } from './repeat';
import { talkPictrueData } from './talkPicture';
import { getDialogueData } from './dialogue';
import { answerQuestionData } from './answerQuestion';
import { replaceAnswerData } from './replaceAnswer';
import { getListenSelectData } from './listenSelect';
import { listenFillData } from './listenFill';
import { getListenJudgeData } from './listenJudge';
import { chineseData } from './chinese';
import { wordCardData } from './wordCard';
import { writeData } from './write';
import { writePictrueData } from './writePicture';
import { readData } from './read';
import { getTableFillData } from './tableFill';
import { wordDictationData } from './wordDictation';

// 题型源数据
export const questionTypeDataOption = [
  {
    value: 'base',
    label: '基础题型',
    children: [
      // data 是为新建题目提供所需的数据
      { label: '选择题', value: 'select', data: getSelectData() },
      { label: '判断题', value: 'judge', data: getJudgeData() },
      { label: '填空题', value: 'fill', data: fillData },
      { label: '排序题', value: 'sort', data: getSortDataTemplate() },
      { label: '连线题', value: 'matching', data: getMatchingDataTemplate() },
      { label: '选择声调', value: 'choose_tone', data: ChooseToneData },
      { label: '问答题', value: 'essay_question', data: essayQuestionData },
      { label: '填表题', value: 'table_fill', data: getTableFillData() },
    ],
  },
  {
    value: 'spoken',
    label: '口语题',
    children: [
      { label: '朗读题', value: 'read_aloud', data: readAloudData },
      { label: '听说训练', value: 'repeat', data: repeatData },
      { label: '看图说话', value: 'talk_picture', data: talkPictrueData },
      { label: '对话题', value: 'dialogue', data: getDialogueData() },
      { label: '口语表达', value: 'answer_question', data: answerQuestionData },
      { label: '替换练习', value: 'replace_answer', data: replaceAnswerData },
    ],
  },
  {
    value: 'hear',
    label: '听力题',
    children: [
      { label: '听后选择', value: 'listen_select', data: getListenSelectData() },
      { label: '听后填空', value: 'listen_fill', data: listenFillData },
      { label: '听后判断', value: 'listen_judge', data: getListenJudgeData() },
    ],
  },
  {
    value: 'character',
    label: '汉字题',
    children: [
      { label: '汉字练习', value: 'chinese', data: chineseData },
      { label: '字词听写', value: 'word_dictation', data: wordDictationData },
      { label: '字词卡片', value: 'word_card', data: wordCardData },
    ],
  },
  {
    value: 'writing',
    label: '写作题',
    children: [
      { label: '基础写作', value: 'write', data: writeData },
      { label: '看图写作', value: 'write_picture', data: writePictrueData },
    ],
  },
  {
    value: 'read',
    label: '阅读题',
    data: readData,
  },
];

// 题型选项
export const questionTypeOption = questionTypeDataOption.map(({ data, ...item }) => {
  if (item.children) {
    item.children = item.children.map(({ data, ...child }) => child);
  }
  return item;
});

// 题型数据列表
export const questionDataList = questionTypeDataOption
  .map(({ data, value, children }) => {
    if (children) return children.map(({ data, value }) => ({ value, data }));
    return { value, data };
  })
  .flat()
  .reduce((obj, { value, data }) => {
    obj[value] = data;
    return obj;
  }, {});

// 练习名称
export const exerciseNames = questionTypeOption
  .map(({ label, value, children }) => {
    if (children) return children;
    return { label, value };
  })
  .flat()
  .reduce((obj, { label, value }) => {
    obj[value] = label;
    return obj;
  }, {});

/**
 * 获取题型类型列表
 * @param {Array} arr 题型类型选项
 * @returns Object
 */
export function getExerciseTypeList(arr) {
  return arr
    .map(({ value, children }) => {
      if (children) {
        return children.map(({ value: children_value }) => {
          return { [children_value]: [value, children_value] };
        });
      }
      return { [value]: [value] };
    })
    .flat()
    .reduce((obj, item) => {
      return { ...obj, ...item };
    }, {});
}

// 题型类型列表
export const exerciseTypeList = getExerciseTypeList(questionTypeOption);
